@@ -896,9 +896,11 @@ class ToastMessage(TypedDict, total=False):
 class BasePlugin(ABC):
     @abstractmethod
     def __init__(self, logger: PluginLogger, api_instance: PluginAPI) -> None: ...
-
     @abstractmethod
-    def on_form_submit(self, action_id: str, payload: Any) -> ToastMessage: ...
-
+    def on_form_submit(
+        self, action_id: str, payload: Any
+    ) -> ToastMessage | Coroutine[Any, Any, ToastMessage]: ...
     @abstractmethod
-    def configure_cameras(self, cameras: List[CameraDevice]) -> None: ...
+    def configure_cameras(
+        self, cameras: List[CameraDevice]
+    ) -> None | Coroutine[Any, Any, None]: ...
